/*  screen.css
	for theme mentalhealth

	blue tints lighter to darker:
		#e6edff
		#bfd3ff
		#607dbf
	border grey:
		#9c9c9c 
*/


/* general */
html {
	background-color: #e6edff;
}
body {
	margin:0;
	padding:0;
	border:0;
    font-size: 1em;
    font-family: Arial, sans-serif;
}
.footnotes div {
	width: 5em;
	border-top: 1px solid #e5e5e5;
}
input {
    font-size: 1em;
    font-family: Arial, sans-serif;
}
textarea {
    font-size: 1em;
    font-family: monospace;
}
span.sep {
    display: none;
}


/****************
	MAIN CONTENT 
*****************/
#page {
    margin: 10px 165px 10px 10px;
	padding: 15px 30px;
	border: 1px solid #9c9c9c;
	border-bottom: 2px solid #9c9c9c;
	background-color: #ffffff;
}
.info {
    font-size: 0.8em;
    color: gray;
}
/* reduced size */
div.codearea pre { 
	margin: 0;
	border: none;
    font-size: 0.8em;
	padding: 0.9em;
	font-family: monospace, courier;
}
/* headers smaller with h2, h3 distinct style */
h2 {
	margin: 1.5em 0 0 0;
	padding: 0 0 0.3em 0;
    border-bottom: 2px solid #607dbf;
	line-height: 1.2em;
}	
h3 {
	margin: 1.5em 0 0 0;
	padding: 0 0 0 0.3em;
	border-left: 10px solid #607dbf;
}	
h1, h4, h5, h6 {
	margin: 0;
	padding: 0;
}
h1 {font-size: 1.6em;}
h2 {font-size: 1.4em;}
h3 {font-size: 1.4em;}
h4 {font-size: 1.2em;}
h5, h6 {font-size: 1em;}


/****************
	UI
*****************/
#header {
    background: #e5e5e5;
    border-bottom: 1px solid #9c9c9c;
}
#logo {
    margin: 0;
    padding: 5px 10px;
    font-weight: bold;
    font-size: 24px;
    line-height: 1em;
    white-space: nowrap;
}
#logo img {
    vertical-align: middle;
}
#logo a {
    color: black;  
    text-decoration: none;
}


/* search form  */
#searchform {
    float: right;
    margin: 5px;
    padding: 0;
    white-space: nowrap;
}
*[dir="rtl"] #searchform {
    float: left;
}
#searchform form div {
    display: inline;
}


/* sidebar */
#sidebar {
	display: inline;
	margin: 10px;
	float: right;
	clear: right;
	width: 145px;
	padding: 0;	
	font-size: 0.88em;
}
.sidepanel {
	margin: 0 0 10px 0;
	float: right;
	width: 145px;	
	border: 1px solid #9c9c9c;
	border-width: 1px 2px 2px 1px;
	font-size: 1.0em;
	background: #bfd3ff;
}
.sidepanel h1 {
	margin: 0;
	padding: 0.2em 10px;
	border: none;
	border-bottom: 1px solid #9c9c9c;
	font-size: 1.0em;
	background: #607dbf;
	color: #e6edff;
}
.sidepanel ul {
	list-style-type: none;
	margin: 0;
	padding:0;
}
.sidepanel li {
	margin: 0;
	padding: 2px 10px;
	border-bottom: 1px solid #9c9c9c;
}
.sidepanel li form {
	margin: 0;
}
.sidepanel a {
	text-decoration: none;
	display: block;
}
.sidepanel a:hover {
	text-decoration: underline;
}
#navibar li.current {
	border: none;
	background: #e6edff;
	border-bottom: 1px solid #9c9c9c;
}

.editbar form, .editbar form div {
    display: inline;
	margin: 0;
}

#credits, #version, #timings{
	float: right;
	clear: right;
	margin: 5px 0;
	width: 145px;
	padding: 0;
	list-style-type: none;
	text-align: center;
	font-size: 0.9em;
	color: gray;
}

#message {
	margin: 10px 220px 10px 10px;
	padding: 5px 10px;
	background-color: #f0ece6;
	border: 1px solid #9c9c9c;
	border-bottom: 2px solid #9c9c9c;
}
#message p{
	margin: 5px 0;
	padding: 0;
	font-weight: bold;
}
#message div.buttons {
	font-weight: normal;
}

form.dialog {
    margin: 0 15px;
}
.dialog td {
    border: none;
    padding: 5px;
}
.dialog td.label {
    text-align: right;
    font-weight: bold;
    width: 25%;
}
*[dir="rtl"] .dialog td.label {
    text-align: left;
}
.dialog td.content input {
    width: 100%;
}

#editor-textarea, #editor-comment {
    width: 95%;
}

#pagebottom {
	clear: both;
}

#preview {
	border: 2px solid #e5e5e5;
	padding: .5em;
	background: url(../img/draft.png);
}

.diff {
	width:99%;
}
.diff-title {
	background-color: #c0c0c0;
}
.diff-added {
	background-color: #e0ffe0;
	vertical-align: sub;
}
.diff-removed {
	background-color: #ffffe0;
	vertical-align: sub;
}
.diff-added span {
	background-color: #80ff80;
}
.diff-removed span {
	background-color: #ffff80;
}
.searchresult dd span {
	font-weight: bold;
}

