/*  projection.css - MoinMoin Slide Styles

Copyright (c) 2003 by Juergen Hermann
*/

@import url("screen.css");

html { line-height: 1.8em; }

body, b, em, a, span, div, p, td { font-size: 22pt; }
/*h1 { font-size: 28pt; } */
h2 { font-size: 24pt; }
h3 { font-size: 22pt; }
h4 { font-size: 20pt; }
h5 { font-size: 18pt; }
h6 { font-size: 16pt; }
tt,pre { font-size: 18pt; }
sup, sub { font-size: 14pt; }

.navigation {
	font-size: 16pt;
	padding-top: 8pt;
	padding-bottom: 8pt;
}

